==> powershare-super-ui-0.6.21.tgz: package/packages/index.js <==
/**
 * @author xiangyu.wu
 * @param { components } 所有组件引入后加入该数组，进行全局安装的循环
 * @param { install } 安装方法
 */

import PsButton from './basicsComponent/button/index'
import PsForm from './basicsComponent/form/index'
import PsFormItem from './basicsComponent/formItem/index'
import PsFormArrItem from './basicsComponent/formArrItem/index'
import PsInput from './basicsComponent/input/index'
import PsRadio from './basicsComponent/radio/index'
import PsCheckBox from './basicsComponent/checkbox/index'
import PsSwitch from './basicsComponent/switch/index'
import PsInputNumber from './basicsComponent/inputNumber/index'
import PsSelect from './basicsComponent/select/index'
import PsTable from './basicsComponent/table/index'
import PsTag from './basicsComponent/tag/index'
import PsUpload from './basicsComponent/upload/index'
import PsUploadFile from './basicsComponent/uploadFile/index'
import PsUploadImage from './basicsComponent/uploadImage/index'
import PsCascader from './basicsComponent/cascader/index'
import PsDrawer from './basicsComponent/drawer/index'
import PsSteps from './basicsComponent/steps/index'
import PsStepsItem from './basicsComponent/stepsItem/index'
import PsCollapse from './basicsComponent/collapse/index'
import PsCollapseItem from './basicsComponent/collapseItem/index'
import PsImageCard from './basicsComponent/imageCard/index'

import PsTabs from './basicsComponent/tabs/index'
import PsDialog from './basicsComponent/dialog/index'

import PsTabsPane from './basicsComponent/tabPane/index'
import PsPagination from './basicsComponent/pagination/index'

// 页面组件
import PsTitle from './pageComponent/title/index'
import PsBlock from './pageComponent/block/index'
import PsDetail from './pageComponent/detail/index'
import PsDetailItem from './pageComponent/detailItem/index'
import PsCardItem from './pageComponent/cardItem/index'
import PsCard from './pageComponent/card/index'
import PsPageButton from './pageComponent/button/index';
import PsSearch from './pageComponent/search/index';
import PsSearchItem from './pageComponent/search/index';
import PsInformation from './pageComponent/information/index';
import PsInformationItem from './pageComponent/informationItem/index';


import './style/index.css';

const components = [PsTabsPane,PsPagination,PsInformation,PsInformationItem, PsSearch,PsSearchItem,PsPageButton, PsButton, PsForm, PsFormItem,PsFormArrItem, PsInput, PsRadio, PsCheckBox, PsSwitch, PsInputNumber, PsSelect, PsTable, PsTitle, PsTag, PsUpload, PsCascader, PsBlock, PsDrawer, PsSteps,PsStepsItem, PsCollapse,PsCollapseItem,PsDetail,PsDetailItem,PsCardItem,PsCard, PsUploadFile, PsImageCard, PsUploadImage, PsTabs, PsDialog]



const install = function (Vue) {
    components.forEach(component => {
        Vue.component(component.name, component);
    });
};

export default {
    install
}

==> powershare-super-ui-0.6.23.tgz: package/packages/index.js <==
/**
 * @author xiangyu.wu
 * @param { components } 所有组件引入后加入该数组，进行全局安装的循环
 * @param { install } 安装方法
 */

import PsButton from './basicsComponent/button/index'
import PsForm from './basicsComponent/form/index'
import PsFormItem from './basicsComponent/formItem/index'
import PsFormArrItem from './basicsComponent/formArrItem/index'
import PsInput from './basicsComponent/input/index'
import PsRadio from './basicsComponent/radio/index'
import PsCheckBox from './basicsComponent/checkbox/index'
import PsSwitch from './basicsComponent/switch/index'
import PsInputNumber from './basicsComponent/inputNumber/index'
import PsSelect from './basicsComponent/select/index'
import PsTable from './basicsComponent/table/index'
import PsTag from './basicsComponent/tag/index'
import PsUpload from './basicsComponent/upload/index'
import PsUploadFile from './basicsComponent/uploadFile/index'
import PsUploadImage from './basicsComponent/uploadImage/index'
import PsCascader from './basicsComponent/cascader/index'
import PsDrawer from './basicsComponent/drawer/index'
import PsSteps from './basicsComponent/steps/index'
import PsStepsItem from './basicsComponent/stepsItem/index'
import PsCollapse from './basicsComponent/collapse/index'
import PsCollapseItem from './basicsComponent/collapseItem/index'
import PsImageCard from './basicsComponent/imageCard/index'

import PsTabs from './basicsComponent/tabs/index'
import PsDialog from './basicsComponent/dialog/index'

import PsTabsPane from './basicsComponent/tabPane/index'
import PsPagination from './basicsComponent/pagination/index'

// 页面组件
import PsTitle from './pageComponent/title/index'
import PsBlock from './pageComponent/block/index'
import PsDetail from './pageComponent/detail/index'
import PsDetailItem from './pageComponent/detailItem/index'
import PsCardItem from './pageComponent/cardItem/index'
import PsCard from './pageComponent/card/index'
import PsPageButton from './pageComponent/button/index';
import PsSearch from './pageComponent/search/index';
import PsSearchItem from './pageComponent/searchItem/index';
import PsInformation from './pageComponent/information/index';
import PsInformationItem from './pageComponent/informationItem/index';


import './style/index.css';

const components = [PsTabsPane,PsPagination,PsInformation,PsInformationItem, PsSearch,PsSearchItem,PsPageButton, PsButton, PsForm, PsFormItem,PsFormArrItem, PsInput, PsRadio, PsCheckBox, PsSwitch, PsInputNumber, PsSelect, PsTable, PsTitle, PsTag, PsUpload, PsCascader, PsBlock, PsDrawer, PsSteps,PsStepsItem, PsCollapse,PsCollapseItem,PsDetail,PsDetailItem,PsCardItem,PsCard, PsUploadFile, PsImageCard, PsUploadImage, PsTabs, PsDialog]



const install = function (Vue) {
    components.forEach(component => {
        Vue.component(component.name, component);
    });
};

export default {
    install
}
